@@ -7,7 +7,7 @@ from vapoursynth import core
 
 class PDeinterlacer:
     """
-    PDeinterlacer (PHOENiX Deinterlacer)
+    PDeinterlacer (PHOENiX Deinterlacer).
     Deinterlaces a clip with the most optimal wrapping based on the sourcer.
     The clip will need to be loaded from PSourcer to work as it needs it's Props.
     """
@@ -27,33 +27,30 @@ class PDeinterlacer:
         if sourcer == "core.imwri.Read":
             # todo ; add support for deinterlacing image data (somehow)
             print("pvsfunc.PDeinterlacer: Warning: This source is a clip of images and cannot be deinterlaced")
-        elif sourcer in ["core.ffms2.Source", "core.lsmas.LWLibavSource"]:
+        elif sourcer in ["core.lsmas.LWLibavSource"]:
             if "FPSDivisor" in kernel_args and kernel_args["FPSDivisor"] != 2:
                 # todo ; ideally make this unnecessary
                 raise ValueError(
-                    f"pvsfunc.PDeinterlacer: {sourcer} only supports QTGMC single-rate output (FPSDivisor=2)"
+                    "pvsfunc.PDeinterlacer: %s only supports QTGMC single-rate output (FPSDivisor=2)" % sourcer
                 )
         self.handler = {
             "core.d2v.Source": self._d2v,
             "core.lsmas.LWLibavSource": self._lsmash,
-            "core.ffms2.Source": self._ffms2,
             "core.imwri.Read": lambda c: c  # NOP
-        }.get(sourcer, None)
+        }.get(sourcer)
         if self.handler is None:
-            raise NotImplementedError(f"pvsfunc.PDeinterlacer: No sourcer is defined for the given media stream")
+            raise NotImplementedError("pvsfunc.PDeinterlacer: No sourcer is defined for the given media stream")
         self.clip = self.handler(self.clip)
 
     def _get_kernel(self, clip) -> tuple:
         """
-        Apply the deinterlacing kernel to the provided clip for both
-        TFF and BFF output. The Kernel function will be provided a
-        True/False value to the "TFF" argument if any.
+        Apply the deinterlacing kernel to the provided clip for both TFF and BFF output.
 
-        Expecting a TFF argument (case-insensitive), it must be present.
-        If the function truly doesn't need it (what??) then wrap it in a lambda, e.g.
-        lambda clip, TFF: yourWeirdFunc(clip)
+        The Kernel function will be provided a True/False value to the "TFF". A "TFF" argument on the kernel
+        function is required, but is not case sensitive. If the function truly doesn't need a field order specification
+        then wrap it in a lambda, e.g. `lambda clip, tff: yourWeirdFunc(clip)`
 
-        Returns 2 clips, one for TFF operations, and one for BFF operations
+        Returns 2 clips, one for TFF operations, and one for BFF operations.
         """
         field_order_arg = [x for x in self.kernel.__code__.co_varnames if x.lower() == "tff"]
         if field_order_arg:
@@ -66,27 +63,28 @@ class PDeinterlacer:
 
     def _d2v(self, clip):
         """
-        Very accurate deinterlacing using raw frame metadata to know what to
-        deinterlace when necessary. It even fixes the frame rates of progressive
-        streams and converts VFR to CFR when necessary.
+        Deinterlace clips that are loaded with core.d2v.Source.
+        It only deinterlaces frames that need to be deinterlaced. It entirely skips frames marked as progressive.
+        It uses DGIndex internally to handle frame indexing as no other Frame indexer I have tested comes anywhere
+        as close as DGIndex's usability and accuracy.
 
-        For MPEG2, this is as good as it gets in terms of using a deinterlacer.
+        Typically used for MPEG Format version 1 and 2 video sources.
         """
         # 1. create a clip from the output of the kernel deinterlacer
         deinterlaced_tff, deinterlaced_bff = self._get_kernel(clip)
         fps_factor = deinterlaced_tff.fps.numerator / deinterlaced_tff.fps.denominator
         fps_factor = fps_factor / (clip.fps.numerator / clip.fps.denominator)
-        if fps_factor != 1.0 and fps_factor != 2.0:
+        if fps_factor not in (1.0, 2.0):
             raise ValueError(
-                f"pvsfunc.PDeinterlacer: The deinterlacer kernel returned an unsupported frame-rate ({deinterlaced_tff.fps}). "
-                "Only single-rate and double-rate is supported with PDeinterlacer at the moment."
+                "pvsfunc.PDeinterlacer: The deinterlacer kernel returned an unsupported frame-rate (%s). "
+                "Only single-rate and double-rate is supported with PDeinterlacer at the moment." % deinterlaced_tff.fps
             )
         fps_factor = int(fps_factor)
 
         # 2. ensure the color families between tff and bff kernel uses match
         if deinterlaced_tff.format.id != deinterlaced_bff.format.id:
             raise ValueError(
-                f"pvsfunc.PDeinterlacer: The kernel used supplied different color space outputs between TFF and BFF usage."
+                "pvsfunc.PDeinterlacer: The kernel supplied different color space outputs between TFF and BFF usage."
             )
 
         # 3. deinterlace whats interlaced
@@ -94,18 +92,18 @@ class PDeinterlacer:
             # compile debug information to print if requested
             debug_info = None
             if self.debug:
-                debug_info = f"VOB: {f.props['PVSFlagVob']}:{f.props['PVSFlagCell']} - Frame #{n:,}"
+                debug_info = "VOB: {:,d}:{:,d} - Frame #{:,d}".format(f.props['PVSFlagVob'], f.props['PVSFlagCell'], n)
             # progressive frame, simply skip deinterlacing
             if f.props["PVSFlagProgressiveFrame"]:
                 rc = core.std.Interleave([c] * ff) if ff > 1 else c  # duplicate if not a single-rate fps output
                 if rc.format.id != d_tff.format.id:
                     rc = core.resize.Point(rc, format=d_tff.format.id)
-                return core.text.Text(rc, f" {debug_info} - Progressive ", alignment=1) if self.debug else rc
+                return core.text.Text(rc, " %s - Progressive " % debug_info, alignment=1) if self.debug else rc
             # interlaced frame, use deinterlaced clip, d_tff if TFF (2) or d_bff if BFF (1)
             rc = {0: c, 1: d_bff, 2: d_tff}[f.props["_FieldBased"]]
             if self.debug:
                 field_order = {0: "Progressive", 1: "BFF", 2: "TFF"}[f.props["_FieldBased"]]
-                return core.text.Text(rc, f" {debug_info} - Deinterlaced ({field_order} ", alignment=1)
+                return core.text.Text(rc, " %s - Deinterlaced (%s) " % (debug_info, field_order), alignment=1)
             return rc
 
         return core.std.FrameEval(
@@ -120,9 +118,14 @@ class PDeinterlacer:
             prop_src=clip
         )
 
-    def _ffms2(self, clip):
+    def _lsmash(self, clip):
         """
-        Deinterlace using ffms2 (ffmpeg) using a basic FieldBased!=0 => QTGMC method
+        Deinterlace clips that are loaded with core.lsmas.LWLibavSource.
+        It only deinterlaces frames that need to be deinterlaced. It entirely skips frames marked as progressive.
+        However, this isn't as perfect as the _d2v method, as it doesn't manually use the frame index data. Instead
+        it assumes LWLibavSource has done it correctly, and assumes it did it at all.
+
+        Typically used for AVC/MPEG-4/H.264 or HEVC/H.265 video sources.
         """
         deinterlaced_tff, deinterlaced_bff = self._get_kernel(clip)
         return core.std.FrameEval(
@@ -144,20 +147,6 @@ class PDeinterlacer:
             prop_src=clip
         )
 
-    def _lsmash(self, clip):
-        """
-        Deinterlace using lsmas (lsmash) using a basic FieldBased!=0 => QTGMC method
-        """
-        return self._ffms2(clip)  # same method as ffms2
-
-    @classmethod
-    def RGBtoYUV(cls, r, g, b):
-        return [
-            (0.257 * r) + (0.504 * g) + (0.098 * b) + 16,
-            -(0.148 * r) - (0.291 * g) + (0.439 * b) + 128,
-            (0.439 * r) - (0.368 * g) - (0.071 * b) + 128
-        ]
-
     @classmethod
     def VoidWeave(cls, clip: vs.VideoNode, tff: bool, color: List[Union[int, float]],
                   bob: bool = False) -> vs.VideoNode:
@@ -174,12 +163,9 @@ class PDeinterlacer:
         actual field clip to be able to weave them together.
         """
         # colors
-        # help needed ; figure out a way to get this working without having to convert colorspace at all
-        # the if color family == YUV RGBtoYUV call is always NOP until then
+        # TODO: figure out a way to get this working without having to convert color-space at all
         if clip.format.name != "RGB24":
             clip = core.resize.Point(clip, format=vs.RGB24)
-        if clip.format.color_family.name == "YUV":
-            color = cls.RGBtoYUV(*color)
         # weave
         clip = core.std.SeparateFields(clip, tff=tff)
         clip = core.std.Interleave([
